@@ -8,7 +8,7 @@
 
 #include <QObject>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct wl_text_input;
 struct wl_text_input_manager;
@@ -18,9 +18,7 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
-class TextInputUnstableV0;
 class Surface;
 class Seat;
 
@@ -41,7 +39,7 @@ class KWAYLANDCLIENT_EXPORT TextInput : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~TextInput();
+    ~TextInput() override;
     /**
      * @returns @c true if managing a resource.
      **/
@@ -114,7 +112,7 @@ public:
      **/
     enum class KeyState {
         Pressed,
-        Released
+        Released,
     };
 
     /**
@@ -164,7 +162,7 @@ public:
         /**
          * the text input is multi line
          */
-        MultiLine = 1 << 9
+        MultiLine = 1 << 9,
     };
     Q_DECLARE_FLAGS(ContentHints, ContentHint)
 
@@ -226,7 +224,7 @@ public:
         /**
          * input for a terminal
          */
-        Terminal
+        Terminal,
     };
     /**
      * Sets the content @p purpose and content @p hints.
@@ -352,7 +350,7 @@ Q_SIGNALS:
      **/
     void inputPanelStateChanged();
     /**
-     * Emitted whenver the text direction changes.
+     * Emitted whenever the text direction changes.
      * @see textDirection
      **/
     void textDirectionChanged();
@@ -418,7 +416,7 @@ class KWAYLANDCLIENT_EXPORT TextInputManager : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~TextInputManager();
+    ~TextInputManager() override;
 
     /**
      * Setup this TextInputManager to manage the @p textinputmanagerunstablev0.
@@ -478,19 +476,19 @@ public:
     /**
      * @returns @c null if not for a wl_text_input_manager
      **/
-    operator wl_text_input_manager*();
+    operator wl_text_input_manager *();
     /**
      * @returns @c null if not for a wl_text_input_manager
      **/
-    operator wl_text_input_manager*() const;
+    operator wl_text_input_manager *() const;
     /**
      * @returns @c null if not for a zwp_text_input_manager_v2
      **/
-    operator zwp_text_input_manager_v2*();
+    operator zwp_text_input_manager_v2 *();
     /**
      * @returns @c null if not for a zwp_text_input_manager_v2
      **/
-    operator zwp_text_input_manager_v2*() const;
+    operator zwp_text_input_manager_v2 *() const;
 
 Q_SIGNALS:
     /**
